@@ -5,8 +5,8 @@ use strict;
 use warnings;
 
 BEGIN {
-    our $VERSION = "0.13";
-    our @EXPORT_OK = qw/parse_urlencoded build_urlencoded/;
+    our $VERSION = "0.14";
+    our @EXPORT_OK = qw/parse_urlencoded build_urlencoded build_urlencoded_utf8/;
 
     my $use_pp = $ENV{WWW_FORM_URLENCODED_PP};
 
@@ -143,6 +143,10 @@ build urlencoded string from B<param>. build_urlencoded accepts arrayref and has
 
 If C<$delim> parameter is passed, this function use it instead of using C<&>.
 
+=item $string = build_urlencoded_utf8(...)
+
+This function is almost same as C<build_urlencoded>. build_urlencoded_utf8 call C<utf8::encode> for all parameters.
+
 =back
 
 =head1 ENVIRONMENT VALUE
